/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Gnu General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Gnu General Public License for more details.
 *
 * You should have received a copy of the Gnu General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import anthill.nest.*;
import anthill.factory.*;
import anthill.util.*;

/**
 *  Class <CODE>LocalManager</CODE> is the implementation of <CODE>Manager</CODE>
 *  to be used during off-line simulations. No thread is used in this implementation;
 *  instead, the execution of the algorithm of a single ant may be forced by invoking
 *  method <CODE>execute()</CODE>. This method is used by <CODE>Scenario</CODE>
 *  implementations in order to force progress of the ant algorithm over the 
 *  simulated network.
 *  
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class LocalManager
implements Manager
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Queue containing the ants to be computed */
  Queue queue;

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  
   */
  public LocalManager()
  {
    queue = new Queue();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Manager
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Adds an ant to the queue of ants to be executed
   *
   *  @param view the ant to be added is encapsulated
   *    in a <CODE>AntView</CODE>
   */
  public void add(AntView view)
  {
    queue.add(view);
  }
  
  
  /**
   *  Executes an ant stored in this <CODE>LocalManager</CODE>. 
   */
  public void execute()
  {
    AntView view = (AntView) queue.remove();
    if (view != null) {
      Ant ant = view.getAnt();
      ant.run(view);
    }
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Clearable
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Restores the object to its initial state.
   */
  public void clear()
  {
    // FIXME Add method clear to queue, in order to avoid re-initializing
    queue = new Queue();
  }
  
} // END Manager
