/*
 * Copyright (c) 2001 The Anthill Team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Gnu General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Gnu General Public License for more details.
 *
 * You should have received a copy of the Gnu General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import anthill.nest.*;
import anthill.factory.*;

import java.util.*;

/**
 *  This class is a simple implementation of <CODE>ResourceSet</CODE>
 *  containing an hash table mapping ant identifiers to response
 *  listeners.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class LocalRequestSet
implements RequestSet
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Map that associates ant identifiers to response listeners */
  HashMap map;
  
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Constructor
   */
  public LocalRequestSet()
  {
    map = new HashMap();
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods 
  ////////////////////////////////////////////////////////////////////////////////////////////

  // Comment inherited from interface RequestSet
  public void add(AntId aid, ResponseListener listener)
  {
    map.put(aid, listener);
  }
  
 
  // Comment inherited from interface RequestSet
  public void returnResources(AntId aid, Resource[] resources)
  {
    ResponseListener listener = (ResponseListener) map.get(aid);
    if (listener != null) {
      listener.returnResources(resources);
    }
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Clearable
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Restores the object to its initial state.
   */
  public void clear()
  {
    map.clear();
  }
  
} // END LocalRequestSet
